import logging
import sys
from argparse import ArgumentParser

from kamikaze3.filesystem_scan.scanner import run_scan
from kamikaze3.log.log import configure_logging

logger = logging.getLogger(__name__)


def parse_args(argv=None):
    p = ArgumentParser(description="Filesystem scanner (backend-only).")
    p.add_argument(
        "--quiet",
        "-q",
        action="store_true",
        help="Suppress all stdout messages",
    )
    p.add_argument("--verbose", "-v", action="store_true", help="Enable debug logging")
    return p.parse_args(argv)


def main(argv=None):
    args = parse_args(argv)
    configure_logging(__name__, getattr(args, "verbose", False))
    if not args.quiet:
        logger.info("[filesystem-scan] starting...")
    try:
        run_scan()
    except Exception as exc:
        logger.error(f"[filesystem-scan] failed: {exc}")
        sys.exit(1)
    if not args.quiet:
        logger.info("[filesystem-scan] done")


if __name__ == "__main__":
    main()
