import logging
import os

logger = logging.getLogger(__name__)


def get_remote_mysql_version(importer):
    """
    Return the remote MySQL major version
    :param importer: Importer object to connect to remote node
    :return str mysql_version: Like '5.7' or '5.6'
    """
    mysql_version_command = 'SHOW VARIABLES WHERE Variable_name = "version";'
    results = importer.remote_db_conn.driver.exec_query(mysql_version_command)

    mysql_version = results[0][
        "Value"
    ]  # Returns a tuple of dicts containing 'Variable_name' and 'Value'
    mysql_major_version = ".".join(mysql_version.split(".")[:2])
    return mysql_major_version


def backup_hipex_mysql_config(importer, backup_dir):
    logger.info(f"Backing up MySQL")
    os.makedirs(backup_dir / "mysql", exist_ok=True)
    importer.file_transfer_conn.driver.download(
        "/etc/my.cnf", backup_dir / "mysql/my.cnf"
    )
    importer.file_transfer_conn.driver.download("/etc/my.cnf.d", backup_dir / "mysql")
