import logging
import re

logger = logging.getLogger(__name__)

DEFAULT_PHP_VERSION = "7.4"


def get_hipex_php_version(importer):
    """
    Get the PHP version of the domain on the Hipex node.
    If not found, we'll set the default PHP version
    :param importer: Importer object to connect to remote node
    :return str php_version | noneType None: Like '5.6' or '7.4'.
    If no PHP version can be detected None is returned.
    """
    return_code, stdout, _ = importer.ssh_conn.driver.exec_command(
        "ps x --sort -start_time"
    )
    if return_code != 0:
        logger.warning("Can't parse PHP version. PHP detection failed, returning None")
        return None

    for line in stdout.strip().decode("utf-8").split("\n"):
        if "php-fpm" in line:
            match = re.match(r".*pool php(\d{2})-.*", line)
            if not match:
                continue

            php_version = match.group(1)

            return "{}.{}".format(php_version[0], php_version[1])
    logger.warning("Could not detect PHP version, returning None")


def backup_hipex_php_config(importer, backup_dir):
    php_version = get_hipex_php_version(importer=importer)
    if php_version:
        logger.info(f"Backing up php '{php_version}'")
        php_short_version = php_version[0:3:2]
        backup_dir.joinpath("php").mkdir(parents=True, exist_ok=True)
        importer.file_transfer_conn.driver.download(
            f"/etc/opt/remi/php{php_short_version}", backup_dir / f"php"
        )
    else:
        logger.info(
            "Because the PHP version was not detected we're not backing "
            "up any PHP settings for reference"
        )
