import logging
from pathlib import Path

logger = logging.getLogger(__name__)


def backup_crontab(importer, backup_dir, file_name="crontab"):
    """
    Backup the crontab of a remote server.

    :param importer: Importer object to connect to remote node
    :param backup_dir: Path to store the backup in
    :param file_name: Name of the file to save the crontab as (default: "crontab")
    :return: True if successful, False otherwise
    """
    logger.info(f"Backing up crontab to {backup_dir / file_name}")
    return_code, stdout, stderr = importer.ssh_conn.driver.exec_command("crontab -l")

    stderr_text = stderr.decode("utf-8", errors="ignore") if stderr else ""

    if return_code != 0:
        logger.warning(
            f"Can't parse crontab, skipping crontab backup. Error: {stderr_text}"
        )
        return False

    stdout_text = stdout.decode("utf-8", errors="ignore")
    with open(backup_dir / file_name, "w") as fp:
        fp.write(stdout_text)
    return True
