import logging
from argparse import ArgumentParser

from kamikaze3.log.log import configure_logging
from kamikaze3.malware_scan.malware_scan import run_scan, update_api

logger = logging.getLogger(__name__)


def parse_arguments(args=None):
    """
    Parse the hypernode-malware-scan arguments
    :param list args: Optional, defaults to sys.argv
    :return obj args: The parsed arguments
    """
    parser = ArgumentParser(
        description="Run Malware scan (Sansec ecomscan) on the hypernode."
    )
    parser.add_argument(
        "path",
        type=str,
        default="/data",
        help="Path to the directory to perform the malware scan on",
    )
    parser.add_argument(
        "--key",
        type=str,
        required=False,
        help="The key to use for the scan. If not provided, use Hypernode default key",
    )
    parser.add_argument(
        "--deep",
        action="store_true",
        help="Scan all files, not just code (not recommended for cron)",
        default=False,
    )
    parser.add_argument(
        "--skip-dashboard",
        action="store_true",
        help="Do not submit scan results to the report dashboard",
        default=False,
    )
    parser.add_argument(
        "--skip-database",
        action="store_true",
        help="Do not scan discovered databases",
        default=False,
    )
    parser.add_argument(
        "--skip-symlinks",
        action="store_true",
        help="Do not follow symlinks (default: do follow)",
        default=False,
    )
    parser.add_argument(
        "--enable-notifications",
        action="store_true",
        help="Notify customers if malware detected",
        default=False,
    )
    parser.add_argument(
        "--verbose", "-v", help="Display debug output", action="store_true"
    )

    parsed_args = parser.parse_args(args)
    return parsed_args


def main():
    args = parse_arguments()
    configure_logging("kamikaze3.malware_scan", args.verbose)

    run_scan(
        args.path,
        key=args.key,
        deep=args.deep,
        skip_dashboard=args.skip_dashboard,
        skip_database=args.skip_database,
        skip_symlinks=args.skip_symlinks,
        enable_notifications=args.enable_notifications,
        verbose=args.verbose,
    )


if __name__ == "__main__":
    main()
